@@ -1137,6 +1137,7 @@ class LkeClient(AbstractClient):
 
     def GetEmbedding(self, request):
         """本接口（GetEmbedding）调用文本表示模型，将文本转化为用数值表示的向量形式，可用于文本检索、信息推荐、知识挖掘等场景。
+        开通[产品体验](https://lke.cloud.tencent.com/lke/#/trialProduct)后可获得50wtoken体验额度。
         本接口（GetEmbedding）有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
 
         :param request: Request instance for GetEmbedding.
@@ -1183,7 +1184,8 @@ class LkeClient(AbstractClient):
 
 
     def GetMsgRecord(self, request):
-        """获取聊天历史请求
+        """获取聊天历史
+        根据会话session id获取聊天历史（仅保留180天内的历史对话数据）
 
         :param request: Request instance for GetMsgRecord.
         :type request: :class:`tencentcloud.lke.v20231130.models.GetMsgRecordRequest`
@@ -2012,7 +2014,7 @@ class LkeClient(AbstractClient):
 
     def QueryRewrite(self, request):
         """多轮改写（QueryRewrite）主要用于多轮对话中，进行指代消解和省略补全。使用本接口，无需输入prompt描述，根据对话历史即可生成更精确的用户查询。在应用场景上，本接口可应用于智能问答、对话式搜索等多种场景。
-        本接口（QueryRewrite）有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
+        开通[产品体验](https://lke.cloud.tencent.com/lke/#/trialProduct)后可获得50wtoken体验额度。本接口（QueryRewrite）有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
 
         :param request: Request instance for QueryRewrite.
         :type request: :class:`tencentcloud.lke.v20231130.models.QueryRewriteRequest`
@@ -2105,29 +2107,6 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def ResetSession(self, request):
-        """重置会话
-
-        :param request: Request instance for ResetSession.
-        :type request: :class:`tencentcloud.lke.v20231130.models.ResetSessionRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.ResetSessionResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("ResetSession", params, headers=headers)
-            response = json.loads(body)
-            model = models.ResetSessionResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def RetryDocAudit(self, request):
         """文档解析重试
 
@@ -2223,9 +2202,9 @@ class LkeClient(AbstractClient):
     def SaveDoc(self, request):
         """知识库文档问答保存。
         将文件存储到应用的知识库内需要三步：
-        1.获取临时密钥，参考[接口文档](https://cloud.tencent.com/document/product/1759/105050)。
-        2.调用腾讯云提供的 cos 存储接口，将文件存储到知识引擎 cos 中：参考[PUT Objectufeff](https://cloud.tencent.com/document/product/436/7749)
-        3.调用本接口，将文件的基础信息存储到知识引擎中。
+        1.获取临时密钥，参考[接口文档](https://cloud.tencent.com/document/product/1759/105050)。获取临时密钥不同参数组合权限不一样，可参考 [智能体开发平台操作 cos 指南](https://cloud.tencent.com/document/product/1759/116238)
+        2.调用腾讯云提供的 cos 存储接口，将文件存储到智能体开发平台 cos 中：具体可参考[ COS SDK 概览](https://cloud.tencent.com/document/product/436/6474), 注意使用的是临时密钥的方式操作 COS
+        3.调用本接口，将文件的基础信息存储到智能体开发平台中。
         以上步骤可参考[文档](https://cloud.tencent.com/document/product/1759/108903)，文档最后有[代码demo](https://cloud.tencent.com/document/product/1759/108903#demo)，可作为参考。
 
         :param request: Request instance for SaveDoc.
