@@ -33,7 +33,7 @@ class LkeapClient(AbstractClient):
         如需使用OpenAI兼容接口， 请参考文档：[Deepseek OpenAI对话接口](https://cloud.tencent.com/document/product/1772/115969)
 
         #### 在线体验
-        如您希望在网页内直接体验 DeepSeek 模型对话，推荐您前往[腾讯云大模型知识引擎](https://cloud.tencent.com/product/lke)，使用[ DeepSeek 联网助手](https://lke.cloud.tencent.com/webim_exp/#/chat/wQrAwR)。
+        如您希望在网页内直接体验 DeepSeek 模型对话，推荐您前往[腾讯云智能体开发平台](https://cloud.tencent.com/product/lke)，使用[ DeepSeek 联网助手](https://lke.cloud.tencent.com/webim_exp/#/chat/wQrAwR)。
 
         #### 已支持的模型
         - DeepSeek-V3-0324（model 参数值为**deepseek-v3-0324**）
@@ -46,6 +46,9 @@ class LkeapClient(AbstractClient):
         - DeepSeek-R1（model 参数值为**deepseek-r1**）
             - DeepSeek-R1为671B模型，使用强化学习训练，推理过程包含大量反思和验证，思维链长度可达数万字。 该系列模型在数学、代码以及各种复杂逻辑推理任务上推理效果优异，并为用户展现了完整的思考过程。
             -  支持96K上下文长度，最大输入长度64k，最大输出16k（默认4k），最大思维链输出长度32k。
+        - DeepSeek-R1-0528（model 参数值为**deepseek-r1-0528**）
+            - DeepSeek-R1-0528为671B 模型，架构优化与训练策略升级后，相比上一版本在代码生成、长文本处理和复杂推理领域提升明显。
+            -  支持96K上下文长度，最大输入长度64k，最大输出16k（默认4k），最大思维链输出长度32k。
         - DeepSeek-Prover-V2（model 参数值为**deepseek-prover-v2**）
             - DeepSeek-Prover-V2 为671B 参数 MoE 模型，在数学定理证明和复杂计算任务中表现出色。
             -  支持64K上下文长度，最大输出16k。
@@ -57,6 +60,8 @@ class LkeapClient(AbstractClient):
 
             -  DeepSeek-R1 模型   | 输入：0.004元/千token | 输出（含思维链）：0.016元/千token
 
+            -  DeepSeek-R1-0528 模型   | 输入：0.004元/千token | 输出（含思维链）：0.016元/千token
+
             - DeepSeek-V3 模型 | 输入：0.002元/千token | 输出：0.008元/千token
 
             - DeepSeek-V3-0324 模型 | 输入：0.002元/千token | 输出：0.008元/千token
